@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -194,7 +194,7 @@ class RedisBus(Bus):
                 if not self.loaded: break
                 self._tick(item, safe = safe)
             except Exception as exception:
-                self.logger.critical("Unhandled redis loop exception raised")
+                self.logger.critical("Unhandled Redis loop exception raised")
                 self.logger.error(exception)
                 lines = traceback.format_exc().splitlines()
                 for line in lines: self.logger.warning(line)
