@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -189,7 +189,8 @@ class TinyAdapter(DataAdapter):
     def drop_db(self, *args, **kwargs):
         if self._db == None: return
         db = self.get_db()
-        db.purge_tables()
+        if hasattr(db, "drop_tables"): db.drop_tables()
+        else: db.purge_tables()
         db.close()
         self._db = None
         method = getattr(self, "_drop_db_%s" % self.storage)
