@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -50,22 +50,44 @@ URL = "redis://localhost"
 """ The default URL to be used for the connection when
 no other URL is provided (used most of the times) """
 
+POOL = True
+""" The default boolean value for the enabling/disabling
+of the connection pool of redis """
+
 connection = None
 """ The global connection object that should persist
 the connection relation with the database service """
 
 class Redis(object):
 
-    def __init__(self, url = None):
+    def __init__(self, url = None, pool = None):
         self.url = url
+        self.pool = pool
         self._connection = None
 
-    def get_connection(self, url = None):
+    def get_connection(self, url = None, pool = None):
         if self._connection: return self._connection
+
         url_c = config.conf("REDISTOGO_URL", None)
         url_c = config.conf("REDIS_URL", url_c)
-        url = url or self.url or url_c or URL
-        self._connection = _redis().from_url(url)
+        pool_c = config.conf("REDIS_POOL", True, cast = bool)
+
+        _url = URL
+        if not url_c == None: _url = url_c
+        if not self.url == None: _url = self.url
+        if not url == None: _url = url
+
+        _pool = POOL
+        if not pool_c == None: _pool = pool_c
+        if not self.pool == None: _pool = self.pool
+        if not pool == None: _pool = pool
+
+        if _pool:
+            connection_pool = _redis().BlockingConnectionPool.from_url(_url)
+            self._connection = _redis().Redis(connection_pool = connection_pool)
+        else:
+            self._connection = _redis().from_url(_url)
+
         return self._connection
 
 def get_connection(url = URL):
@@ -73,7 +95,12 @@ def get_connection(url = URL):
     if connection: return connection
     url = config.conf("REDISTOGO_URL", url)
     url = config.conf("REDIS_URL", url)
-    connection = _redis().from_url(url)
+    pool = config.conf("REDIS_POOL", True, cast = bool)
+    if pool:
+        connection_pool = _redis().BlockingConnectionPool.from_url(url)
+        connection = _redis().Redis(connection_pool = connection_pool)
+    else:
+        connection = _redis().from_url(url)
     return connection
 
 def dumps(*args):
