@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -457,13 +457,13 @@ def install_pip_s(package, delayed = False):
 def request_json(request = None, encoding = "utf-8"):
     # retrieves the proper request object, either the provided
     # request or the default base request object and then in
-    # case the the json data is already in the request properties
+    # case the the JSON data is already in the request properties
     # it is used (cached value) otherwise continues with the parse
     request = request or common.base().get_request()
     if "_data_j" in request.properties: return request.properties["_data_j"]
 
     # retrieves the current request data and tries to
-    # "load" it as json data, in case it fails gracefully
+    # "load" it as JSON data, in case it fails gracefully
     # handles the failure setting the value as an empty map
     data = request.data
     try:
@@ -474,7 +474,7 @@ def request_json(request = None, encoding = "utf-8"):
         data_j = {}
     request.properties["_data_j"] = data_j
 
-    # returns the json data object to the caller method so that it
+    # returns the JSON data object to the caller method so that it
     # may be used as the parsed value (post information)
     return data_j
 
@@ -524,7 +524,7 @@ def get_object(
     object = object and copy.copy(object) or {}
 
     # retrieves the current request data and tries to
-    # "load" it as json data, in case it fails gracefully
+    # "load" it as JSON data, in case it fails gracefully
     # handles the failure setting the value as an empty map
     data_j = request_json()
 
@@ -993,21 +993,26 @@ def unquote(value, *args, **kwargs):
 def escape(value, char, escape = "\\"):
     """
     Escapes the provided string value according to the requested
-    target character and escape value. Meaning that all the characters
+    target character(s) and escape value. Meaning that all the characters
     are going to be replaced by the escape plus character sequence.
 
     :type value: String
     :param value: The string that is going to have the target characters
     escaped according to the escape character.
-    :type char: String
-    :param char: The character that is going to be "target" of escaping.
+    :type char: String/List/Tuple
+    :param char: The character(s) that is going to be "target" of escaping
+    or a list of characters for escaping.
     :type escape: String
-    :param escape: The character to be used for escaping (normally`\`).
+    :param escape: The character to be used for escaping (typically `\`).
     :rtype: String
     :return: The final string with the target character properly escaped.
     """
 
-    return value.replace(escape, escape + escape).replace(char, escape + char)
+    if not isinstance(char, (list, tuple)): char = (char,)
+    value = value.replace(escape, escape + escape)
+    for _char in char:
+        value = value.replace(_char, escape + _char)
+    return value
 
 def unescape(value, escape = "\\"):
     """
@@ -1740,6 +1745,30 @@ def to_tokens_m(tokens):
     return tokens_m
 
 def dict_merge(first, second, override = True, recursive = False):
+    """
+    Merges two dictionaries, optionally using a deep (recursive)
+    strategy to achieve the merge.
+
+    The default "way" of the merge is from the second to the first
+    and overriding the values of the first dictionary.
+
+    :type first: Dictionary
+    :param first: The target dictionary of the merge operation and
+    that will have its contents overriden if requested.
+    :type second: Dictionary
+    :param second: The base dictionary of the merge that will be
+    "copied" into the first one.
+    :type override: bool
+    :param override: If the contents of the first dictionary should
+    be overriden (overwritten) in case of "collision".
+    :type recursive: bool
+    :param recursive: If the merge operation should be performed using
+    a deep and recursive approach for dictionary types.
+    :rtype: Dictionary
+    :return: The resulting dictionary (new instance) from the merge
+    operation of the second dictionary into the first.
+    """
+
     # in case no override exists then the order of the items is
     # exchanged so that the first overrides the second values
     # and not the exact opposite
@@ -1769,6 +1798,7 @@ def dict_merge(first, second, override = True, recursive = False):
             # it's of any other type (no smart merge possible)
             other = second[key]
             if isinstance(value, dict) and isinstance(other, dict):
+                if not override: value, other = other, value
                 final[key] = dict_merge(
                     value,
                     other,
@@ -1915,7 +1945,14 @@ def delayed(function):
 
     return _delayed
 
-def route(url, method = "GET", asynchronous = False, json = False, opts = None):
+def route(
+    url,
+    method = "GET",
+    asynchronous = False,
+    json = False,
+    opts = None,
+    priority = 1
+):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
@@ -1925,13 +1962,14 @@ def route(url, method = "GET", asynchronous = False, json = False, opts = None):
             function,
             asynchronous = asynchronous,
             json = json,
-            opts = opts
+            opts = opts,
+            priority = priority
         )
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        route = (url, method, asynchronous, json, opts)
+        route = (url, method, asynchronous, json, opts, priority)
         if not hasattr(function, "_routes"): function._routes = []
         function._routes.append(route)
         function.creation_counter = CREATION_COUNTER
@@ -1939,7 +1977,7 @@ def route(url, method = "GET", asynchronous = False, json = False, opts = None):
 
     return decorator
 
-def error_handler(code, scope = None, json = False, opts = None):
+def error_handler(code, scope = None, json = False, opts = None, priority = 1):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
@@ -1947,13 +1985,14 @@ def error_handler(code, scope = None, json = False, opts = None):
             code,
             function,
             json = json,
-            opts = opts
+            opts = opts,
+            priority = priority
         )
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        error = (code, scope, json, opts)
+        error = (code, scope, json, opts, priority)
         if not hasattr(function, "_errors"): function._errors = []
         function._errors.append(error)
         function.creation_counter = CREATION_COUNTER
@@ -1962,7 +2001,7 @@ def error_handler(code, scope = None, json = False, opts = None):
 
     return decorator
 
-def exception_handler(exception, scope = None, json = False, opts = None):
+def exception_handler(exception, scope = None, json = False, opts = None, priority = 1):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
@@ -1970,13 +2009,14 @@ def exception_handler(exception, scope = None, json = False, opts = None):
             exception,
             function,
             json = json,
-            opts = opts
+            opts = opts,
+            priority = priority
         )
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        _exception = (exception, scope, json, opts)
+        _exception = (exception, scope, json, opts, priority)
         if not hasattr(function, "_exceptions"): function._exceptions = []
         function._exceptions.append(_exception)
         function.creation_counter = CREATION_COUNTER
@@ -1985,16 +2025,21 @@ def exception_handler(exception, scope = None, json = False, opts = None):
 
     return decorator
 
-def before_request(scope = "all", opts = None):
+def before_request(scope = "all", opts = None, priority = 1):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
-        else: common.base().App.add_custom("before_request", function, opts = opts)
+        else: common.base().App.add_custom(
+            "before_request",
+            function,
+            opts = opts,
+            priority = priority
+        )
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        _custom = ("before_request", opts)
+        _custom = ("before_request", opts, priority)
         if not hasattr(function, "_customs"): function._customs = []
         function._customs.append(_custom)
         function.creation_counter = CREATION_COUNTER
@@ -2003,16 +2048,21 @@ def before_request(scope = "all", opts = None):
 
     return decorator
 
-def after_request(scope = "all", opts = None):
+def after_request(scope = "all", opts = None, priority = 1):
 
     def decorator(function, *args, **kwargs):
         if is_detached(function): delay(function, *args, **kwargs)
-        else: common.base().App.add_custom("after_request", function, opts = opts)
+        else: common.base().App.add_custom(
+            "after_request",
+            function,
+            opts = opts,
+            priority = priority
+        )
         return function
 
     def delay(function, *args, **kwargs):
         global CREATION_COUNTER
-        _custom = ("after_request", opts)
+        _custom = ("after_request", opts, priority)
         if not hasattr(function, "_customs"): function._customs = []
         function._customs.append(_custom)
         function.creation_counter = CREATION_COUNTER
@@ -2094,6 +2144,16 @@ def verify_not_equal(first, second, message = None, code = None, exception = Non
         **kwargs
     )
 
+def verify_type(value, types, null = True, message = None, code = None, exception = None, **kwargs):
+    message = message or "Expected %s to have type %s" % (repr(value), repr(types))
+    return verify(
+        (null and value == None) or isinstance(value, types),
+        message = message,
+        code = code,
+        exception = exception,
+        **kwargs
+    )
+
 def verify_many(sequence, message = None, code = None, exception = None, **kwargs):
     for condition in sequence:
         verify(
@@ -2210,6 +2270,9 @@ class FileTuple(tuple):
         finally:
             if close: file.close()
 
+    def seekable(self):
+        return True
+
     @property
     def name(self):
         return self[0]
